package com.fossgalaxy.games.ggj2017;

import com.fossgalaxy.games.rts.GameState;
import com.fossgalaxy.games.rts.entity.Entity;
import com.fossgalaxy.games.rts.entity.Resource;
import com.fossgalaxy.games.rts.entity.ResourceType;
import com.fossgalaxy.games.rts.order.Order;
import com.fossgalaxy.object.annotations.ObjectDef;
import org.codetome.hexameter.core.api.CubeCoordinate;

import java.awt.*;

public class MinesAction extends DroneAction {
    private static final Color HINT_MINE_COLOUR = new Color(0, 0, 0, 0);
    private static final Stroke HINT_STROKE = new BasicStroke(2f);

    private ResourceType resourceType;
    private int quantityPerTurn;

    @ObjectDef("Mine")
    public MinesAction(ResourceType resourceType, int quantityPerTurn) {
        this.resourceType = resourceType;
        this.quantityPerTurn = quantityPerTurn;
    }

    @Override
    public void renderHints(Graphics2D graphics2D, GameState gameState, Entity entity) {
        // Deliberately do nothing here
    }

    @Override
    public Order generateOrder(CubeCoordinate cubeCoordinate, GameState gameState) {
        return new MineOrder(resourceType, quantityPerTurn);
    }

    @Override
    public boolean isPossible(Entity entity, GameState s, CubeCoordinate co) {
        if(! super.isPossible(entity, s, co)) return false;

        Resource resource = s.getResourceAt(co);
        if(resource == null) return false;
        if(resource.getAmountPerTurn() <= 0) return false;

        return true;
    }

    @Override
    public boolean canAutomate() {
        return true;
    }

    @Override
    public boolean isPossible(Entity entity) {
        return true;
    }

    @Override
    public Color getHintColour() {
        return HINT_MINE_COLOUR;
    }

    @Override
    public Color getBorderColour() {
        return HINT_MINE_COLOUR;
    }

    @Override
    public String toString() {
        return "Mine: " + resourceType.getName();
    }
}
